<?php
/**
 * @package         FireBox
 * @version         1.0.13 Free
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FireBox\Core\Admin\Forms\FireBox;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

use FPFramework\Helpers\AnimationsHelper;

class Design
{
	/**
	 * Holds the Design Settings
	 * 
	 * @return  array
	 */
	public function getSettings()
	{
		$settings = [
			'title' => 'FPF_DESIGN',
			'content' => [
				'popup_size' => [
					'title' => [
						'title' => 'FB_METABOX_DESIGN_POPUP_SIZE',
						'description' => 'FB_METABOX_DESIGN_POPUP_SIZE_DESC'
					],
					'fields' => [
						[
							'name' => 'width_control',
							'type' => 'ResponsiveControl',
							'label' => 'FPF_WIDTH',
							'class' => ['small-12', 'medium-auto'],
							'fields' => [
								[
									'name' => 'width',
									'type' => 'Number',
									'label' => 'FPF_WIDTH',
									'input_class' => ['fullwidth'],
									'placeholder' => '500',
									'default' => '500',
									'units' => ['px', '%'],
									'units_relative_position' => false,
									'render_group' => false
								],
							]
						],
						[
							'name' => 'height_control',
							'type' => 'ResponsiveControl',
							'label' => 'FPF_HEIGHT',
							'class' => ['small-12', 'medium-auto'],
							'fields' => [
								[
									'name' => 'height',
									'type' => 'Number',
									'input_class' => ['fullwidth'],
									'placeholder' => '300',
									'units' => ['px', '%', 'auto'],
									'units_default' => 'auto',
									'units_relative_position' => false,
									'render_group' => false
								]
							]
						]
					]
				],
				'box' => [
					'title' => [
						'title' => 'FB_METABOX_DESIGN_POPUP',
						'description' => 'FB_METABOX_DESIGN_POPUP_DESC'
					],
					'fields' => [
						[
							'name' => 'padding_control',
							'type' => 'ResponsiveControl',
							'label' => 'FPF_PADDING',
							'description' => 'FB_METABOX_PADDING_DESC',
							'control_inner_class' => ['fpf-max-width-300'],
							'fields' => [
								[
									'name' => 'padding',
									'type' => 'Dimensions',
									'label' => 'FPF_PADDING',
									'default' => 30,
									'units' => ['px', '%'],
									'units_relative_position' => false,
									'render_group' => false,
									'isLinked' => true
								],
							]
						],
						[
							'name' => 'margin_control',
							'type' => 'ResponsiveControl',
							'label' => 'FPF_MARGIN',
							'description' => 'FB_METABOX_MARGIN_DESC',
							'control_inner_class' => ['fpf-max-width-300'],
							'fields' => [
								[
									'name' => 'margin',
									'type' => 'Dimensions',
									'label' => 'FPF_MARGIN',
									'units' => ['px', '%'],
									'render_group' => false,
									'units_relative_position' => false,
									'isLinked' => true
								],
							]
						],
						[
							'name' => 'textcolor',
							'type' => 'Color',
							'label' => 'FPF_TEXT_COLOR',
							'default' => '#444444',
						],
						[
							'name' => 'backgroundcolor',
							'type' => 'Color',
							'label' => 'FPF_BG_COLOR',
							'default' => '#ffffff'
						],
						[
							'name' => 'aligncontent',
							'type' => 'Dropdown',
							'label' => 'FPF_TEXT_POSITION',
							'choices' => [
								'acl' => 'FB_METABOX_POSITION_TL',
								'act acc' => 'FB_METABOX_POSITION_TC',
								'act acr' => 'FB_METABOX_POSITION_TR',
								'acm acl' => 'FB_METABOX_POSITION_ML',
								'acm acc' => 'FB_METABOX_POSITION_MC',
								'acm acr' => 'FB_METABOX_POSITION_MR',
								'acb acl' => 'FB_METABOX_POSITION_BL',
								'acb acc' => 'FB_METABOX_POSITION_BC',
								'acb acr' => 'FB_METABOX_POSITION_BR'
							],
							'filter' => 'sanitize_text_field'
						],
						[
							'name' => 'boxshadow',
							'type' => 'Toggle',
							'label' => 'FB_METABOX_SHADOW',
							'input_class' => ['default'],
							'choices' => [
								'0' => 'FPF_NONE',
								'1' => 'FB_METABOX_SHADOW_S1',
								'2' => 'FB_METABOX_SHADOW_S2',
								'3' => 'FB_METABOX_SHADOW_S3',
								'elevation' => 'FB_ELEVATION'
							]
						],
					]
				],
				'close_button' => [
					'title' => [
						'title' => 'FB_METABOX_CLOSE_BUTTON',
						'description' => 'FB_METABOX_CLOSE_BUTTON_TITLE_DESC'
					],
					'fields' => [
						[
							'name' => 'closebutton.show',
							'type' => 'Toggle',
							'input_class' => ['default'],
							'default' => 1,
							'choices' => [
								1 => 'FB_METABOX_CLOSE_BUTTON_INSIDE',
								2 => 'FB_METABOX_CLOSE_BUTTON_OUTSIDE',
								0 => 'FPF_HIDE'
							]
						],
						[
							'name' => 'closebutton.source',
							'type' => 'Toggle',
							'label' => 'FB_METABOX_CLOSE_BUTTON_TYPE',
							'default' => 'icon',
							'choices' => [
								'icon' => 'FPF_ICON',
								'image' => 'FPF_IMAGE'
							],
							'showon' => '[closebutton][show]:1,2'
						],
						[
							'name' => 'closebutton.color',
							'type' => 'Color',
							'label' => 'FPF_COLOR',
							'default' => 'rgba(136, 136, 136, 1)',
							'showon' => '[closebutton][source]:icon[AND][closebutton][show]:1,2'
						],
						[
							'name' => 'closebutton.hover',
							'type' => 'Color',
							'label' => 'FB_METABOX_HOVER_COLOR',
							'default' => 'rgba(85, 85, 85, 1)',
							'showon' => '[closebutton][source]:icon[AND][closebutton][show]:1,2'
						],
						[
							'name' => 'closebutton.size',
							'type' => 'Slider',
							'label' => 'FPF_FONT_SIZE',
							'number_class' => ['xsmall'],
							'default' => 30,
							'step' => 2,
							'addon' => 'px',
							'showon' => '[closebutton][source]:icon[AND][closebutton][show]:1,2'
						],
						[
							'name' => 'closebutton.image',
							'type' => 'MediaUploader',
							'label' => 'FPF_SELECT_IMAGE',
							'description' => 'FB_METABOX_SELECT_IMAGE_DESC',
							'showon' => '[closebutton][source]:image[AND][closebutton][show]:1,2',
							'filter' => 'esc_url_raw'
						],
						[
							'name' => 'closebutton.delay',
							'type' => 'Slider',
							'label' => 'FB_METABOX_DELAY',
							'default' => 0,
							'min' => 0,
							'max' => 120,
							'step' => 2,
							'addon' => 'sec',
							'showon' => '[closebutton][show]:1,2'
						],
					]
				],
				'animation' => [
					'title' => [
						'title' => 'FB_METABOX_ANIMATION',
						'description' => 'FB_METABOX_ANIMATION_DESC',
					],
					'fields' => [
						[
							'name' => 'animationin',
							'type' => 'SearchDropdown',
							'label' => 'FB_METABOX_ANIMATION_IN',
							'default' => ['transition.slideUpIn'],
							'control_inner_class' => ['fpf-fullwidth'],
							'placeholder' => 'FB_TRANSITION_IN_HINT',
							'hide_ids' => true,
							'multiple' => false,
							'items' => AnimationsHelper::getTransitionsIn(),
							'filter' => 'sanitize_text_field',
							'class' => ['medium-auto'],
							'input_class' => ['fullwidth']
						],
						[
							'name' => 'animationout',
							'type' => 'SearchDropdown',
							'label' => 'FB_METABOX_ANIMATION_OUT',
							'default' => ['transition.fadeOut'],
							'control_inner_class' => ['fpf-fullwidth'],
							'placeholder' => 'FB_TRANSITION_OUT_HINT',
							'hide_ids' => true,
							'multiple' => false,
							'items' => AnimationsHelper::getTransitionsOut(),
							'filter' => 'sanitize_text_field',
							'class' => ['medium-auto'],
							'input_class' => ['fullwidth']
						],
						[
							'name' => 'duration',
							'type' => 'Slider',
							'label' => 'FB_METABOX_DURATION',
							'default' => 0.3,
							'min' => 0,
							'max' => 2,
							'step' => 0.1,
							'addon' => 'sec'
						]
					]
				],
				'border' => [
					'title' => [
						'title' => 'FPF_BORDER',
						'description' => 'FPF_BORDER_DESC'
					],
					'fields' => [
						[
							'name' => 'bordertype',
							'type' => 'Dropdown',
							'label' => 'FPF_STYLE',
							'default' => 'solid',
							'choices' => [
								'none' => 'FPF_NONE',
								'solid' => 'FPF_SOLID',
								'dotted' => 'FPF_DOTTED',
								'dashed' => 'FPF_DASHED',
								'inset' => 'FPF_INSET',
								'outset' => 'FPF_OUTSET',
								'groove' => 'FPF_GROOVE',
								'ridge' => 'FPF_RIDGE',
								'hidden' => 'FPF_HIDDEN'
							],
						],
						[
							'name' => 'bordercolor',
							'type' => 'Color',
							'label' => 'FPF_COLOR',
							'default' => 'rgba(0, 0, 0, 0.4)',
							'showon' => '[bordertype]!:none'
						],
						[
							'name' => 'borderwidth',
							'type' => 'Slider',
							'label' => 'FPF_WIDTH',
							'number_class' => ['xsmall'],
							'default' => 1,
							'min' => 0,
							'max' => 15,
							'units' => ['px'],
							'showon' => '[bordertype]!:none'
						],
						[
							'name' => 'borderradius_control',
							'type' => 'ResponsiveControl',
							'label' => 'FB_METABOX_BORDERRADIUS',
							'description' => 'FB_METABOX_BORDERRADIUS_DESC',
							'control_inner_class' => ['fpf-max-width-300'],
							'fields' => [
								[
									'name' => 'borderradius',
									'type' => 'Dimensions',
									'default' => 0,
									'max' => 100,
									'units' => ['px', '%'],
									'units_relative_position' => false,
									'isLinked' => true,
									'labels' => [
										'top_left' => fpframework()->_('FPF_TOP_LEFT'),
										'top_right' => fpframework()->_('FPF_TOP_RIGHT'),
										'bottom_right' => fpframework()->_('FPF_BOTTOM_RIGHT'),
										'bottom_left' => fpframework()->_('FPF_BOTTOM_LEFT')
									]
								]
							]
						],
					]
				],
				'background_overlay' => [
					'title' => [
						'title' => 'FB_METABOX_BG_OVERLAY',
						'description' => 'FB_METABOX_BG_OVERLAY_DESC'
					],
					'fields' => [
						[
							'name' => 'overlay',
							'type' => 'FPToggle'
						],
						[
							'name' => 'overlay_color',
							'type' => 'Color',
							'label' => 'FPF_BG_COLOR',
							'description' => 'FB_METABOX_OVERLAY_COLOR_DESC',
							'default' => 'rgba(0, 0, 0, 0.5)',
							'showon' => '[overlay]:1'
						],
						[
							'name' => 'overlayclick',
							'type' => 'FPToggle',
							'label' => 'FB_METABOX_OVERLAY_CLICK',
							'description' => 'FB_METABOX_OVERLAY_CLICK_DESC',
							'checked' => true,
							'showon' => '[overlay]:1'
						]
					]
				],
				'background_image' => [
					'title' => [
						'title' => 'FPF_BG_IMAGE',
						'description' => 'FPF_BG_IMAGE_DESC'
					],
					'fields' => [
						[
							'name' => 'bgimage',
							'type' => 'FPToggle'
						],
						[
							'name' => 'bgimagefile',
							'type' => 'MediaUploader',
							'label' => 'FPF_IMAGE',
							'description' => 'FB_METABOX_BG_IMAGE_FILE_DESC',
							'showon' => '[bgimage]:1'
						],
						[
							'name' => 'bgrepeat',
							'type' => 'Dropdown',
							'label' => 'FPF_REPEAT',
							'description' => 'FB_METABOX_BGREPEAT_DESC',
							'default' => 'Repeat',
							'choices' => [
								'No-repeat' => 'FB_METABOX_BGREPEAT_NOREPEAT',
								'Repeat' => 'FPF_REPEAT',
								'Repeat-x' => 'FB_METABOX_BGREPEAT_REPEATX',
								'Repeat-y' => 'FB_METABOX_BGREPEAT_REPEATY'
							],
							'filter' => 'sanitize_text_field',
							'showon' => '[bgimage]:1'
						],
						[
							'name' => 'bgsize',
							'type' => 'Dropdown',
							'label' => 'FPF_SIZE',
							'description' => 'FB_METABOX_BGSIZE_DESC',
							'default' => 'Auto',
							'choices' => [
								'Auto' => 'FPF_AUTO',
								'Cover' => 'FB_METABOX_BGSIZE_COVER',
								'Contain' => 'FB_METABOX_BGSIZE_CONTAIN',
								'100% 100%' => '100% 100%'
							],
							'filter' => 'sanitize_text_field',
							'showon' => '[bgimage]:1'
						],
						[
							'name' => 'bgposition',
							'type' => 'Dropdown',
							'label' => 'FPF_POSITION',
							'description' => 'FB_METABOX_BG_POSITION_DESC',
							'default' => 'Left Top',
							'choices' => [
								'Left Top' => 'FB_METABOX_BG_POSITION_LEFT_TOP',
								'Left Center' => 'FB_METABOX_BG_POSITION_LEFT_CENTER',
								'Left Bottom' => 'FB_METABOX_BG_POSITION_LEFT_BOTTOM',
								'Right Top' => 'FB_METABOX_BG_POSITION_RIGHT_TOP',
								'Right Center' => 'FB_METABOX_BG_POSITION_RIGHT_CENTER',
								'Right Bottom' => 'FB_METABOX_BG_POSITION_RIGHT_BOTTOM',
								'Center Top' => 'FB_METABOX_BG_POSITION_CENTER_TOP',
								'Center Center' => 'FB_METABOX_BG_POSITION_CENTER_CENTER',
								'Center Bottom' => 'FB_METABOX_BG_POSITION_CENTER_BOTTOM'
							],
							'filter' => 'sanitize_text_field',
							'showon' => '[bgimage]:1'
						]
					]
				]
			]
		];

		return apply_filters('firebox/box/settings/design/edit', $settings);
	}
}