<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.27
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Base\Assignments;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

use FPFramework\Base\Assignment;

class Cookie extends Assignment
{
    public function pass()
    {
        $pass = false;
        $cookie_data        = $this->value();
        $user_content       = empty($this->params->content) ? '' : $this->params->content;

        // return false if the cookie is not found
        if($cookie_data === null)
        {
            return false;
        }

        // return true if the user selected the 'exists' option
        if ($this->selection === 'exists')
        {
            return true;
        }

        switch ($this->selection)
        {
            case 'equal':
                $pass = $user_content === $cookie_data;
                break;
            case 'contains':
                if ($user_content !== '' && strpos($cookie_data, $user_content) !== FALSE)
                {
                    $pass = true;
                }
                break;
            case 'starts':
                if ($user_content !== '' && substr($cookie_data, 0, strlen($user_content)) === $user_content)
                {
                    $pass = true;
                }
                break;
            case 'ends':
                if ($user_content !== '' && substr($cookie_data, -strlen($user_content)) === $user_content)
                {
                    $pass = true;
                }
                break;
        }

        return $pass;
    }

    /**
     *  Returns the assignment's value
     * 
     *  @return string Cookie data
     */
	public function value()
	{
		return $this->factory->getCookie($this->params->name)->get();
	}
}
