<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.27
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Base\Assignments;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

use FPFramework\Base\Assignment;

class Timeonsite extends Assignment
{
    /**
	 *  Pass - Check User's Time on Site
	 *
	 *  @return  bool
	 */
	public function pass()
	{
        $pass = false;
        
        $diffInSeconds = $this->getTimeOnSite();
        if (!$diffInSeconds)
        {
            return $pass;
        }

		if (intval($this->selection) <= $diffInSeconds)
		{
			$pass = true;
		}

		return $pass;
	}

    /**
     *  Returns the assignment's value
     * 
     *  @return int Time on site in seconds
     */
	public function value()
	{
		return $this->getTimeOnSite();
    }
    
    /**
     *  Returns the user's time on site in seconds
     * 
     *  @return int
     */
    public function getTimeOnSite()
    {
        $sessionStartTime = strtotime($this->getSessionStartTime());

		if (!$sessionStartTime)
		{
			return;
		}

		$dateTimeNow = strtotime(\FPFramework\Libs\Functions::dateTimeNow());
		return $dateTimeNow - $sessionStartTime;
    }

    /**
     *  Returns the sessions start time
     * 
     *  @return string
     */
    private function getSessionStartTime()
    {
        $session = $this->factory->getSession();
        
        $var = 'starttime';
        $sessionStartTime = $session->get($var);

        if (!$sessionStartTime)
        {
            $date = \FPFramework\Libs\Functions::dateTimeNow();
            $session->set($var, $date);
        }

        return $session->get($var);
    }
}