<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.27
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Helpers;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

class Directory
{
	/**
	 * Copies files from source to directory
	 * 
	 * @param   string  $src
	 * @param   string  $dest
	 * 
	 * @return  void
	 */
	public static function copy($src, $dest)
	{
		$dir = opendir($src);

		mkdir($dest);

		while(false !== ($file = readdir($dir)))
		{
			if (in_array($file, ['.', '..']))
			{
				continue;
			}
		
			if (is_dir($src . DIRECTORY_SEPARATOR . $file))
			{
				self::copy($src . DIRECTORY_SEPARATOR . $file, $dest . DIRECTORY_SEPARATOR . $file);
			}
			else
			{
				copy($src . DIRECTORY_SEPARATOR . $file, $dest . DIRECTORY_SEPARATOR . $file);
			}
        }

		closedir($dir);
	}

	/**
	 * Creates a directory
	 * 
	 * @param   string  $dir
	 * 
	 * @return  mixed
	 */
	public static function create($dir)
	{
		if (!$dir)
		{
			return;
		}
		
		if (file_exists($dir))
		{
			return;
		}
		
		mkdir($dir);
	}

	/**
	 * Empties a directory
	 * 
	 * @param   string  $dir
	 * 
	 * @return  mixed
	 */
	public static function empty($dir)
	{
		if (!file_exists($dir))
		{
			return;
		}

		$it = new \RecursiveDirectoryIterator($dir, \RecursiveDirectoryIterator::SKIP_DOTS);
		$files = new \RecursiveIteratorIterator($it,
					\RecursiveIteratorIterator::CHILD_FIRST);
		
		foreach($files as $file)
		{
			if ($file->isDir())
			{
				rmdir($file->getRealPath());
			}
			else
			{
				unlink($file->getRealPath());
			}
		}
	}

	/**
	 * Deletes a directory
	 * 
	 * @param   string  $dir
	 * 
	 * @return  mixed
	 */
	public static function delete($dir)
	{
		if (!$dir)
		{
			return;
		}
		
		if (!file_exists($dir))
		{
			return;
		}

		self::empty($dir);

		rmdir($dir);
	}
}